# MASS Bioactive Fractions Filtering

## Install

MS-BFF package has been uploaded to PyPI, so you can install it by pip conveniently.

```bash
pip install msbff
```



## Main Function

- Module 1 Preprocessing data: Read data and perform data cleaning

- Module 2 Processing data: Calculate each variable value.

- Module 3 Data visualization: Plot one line chart and three heatmap.



## Usage

### Help

Run the command and view the help information.

```bash
msbff -h
```



### Example

You can run the command with the default parameters and the output files will be saved in a specified folder.

```bash
mkdir output  # create output folder
msbff -i rawdata.csv -o output  # run msbff in default
```





### Output Files

- 



## Contact

Don't hesitate to contact me by email if you have any problems.

E-mail: gavinchou64@gmail.com